Name:           apache-commons-net
Version:        3.11.1
Release:        %mkrel 1
Group:          Development/Java
Summary:        Internet protocol suite Java library
License:        Apache-2.0
URL:            https://commons.apache.org/net/
Source0:        https://archive.apache.org/dist/commons/net/source/commons-net-%{version}-src.tar.gz
Source1:        https://downloads.apache.org/commons/net/source/commons-net-%{version}-src.tar.gz.asc
Source2:        https://downloads.apache.org/commons/KEYS
BuildArch:      noarch
#ExclusiveArch:  %%{java_arches} noarch

BuildRequires:  maven-local
BuildRequires:  mvn(commons-io:commons-io)
BuildRequires:  mvn(org.apache.commons:commons-lang3)
BuildRequires:  mvn(org.apache.commons:commons-parent:pom:)
BuildRequires:  mvn(org.apache.maven.plugins:maven-antrun-plugin)
BuildRequires:  mvn(org.codehaus.mojo:build-helper-maven-plugin)
BuildRequires:  mvn(org.junit.jupiter:junit-jupiter-api)
BuildRequires:  mvn(org.junit.jupiter:junit-jupiter-engine)
BuildRequires:  mvn(org.junit.jupiter:junit-jupiter-params)
BuildRequires:  mvn(org.junit.vintage:junit-vintage-engine)

BuildRequires:  gnupg2

%description
This is an Internet protocol suite Java library originally developed by
ORO, Inc.  This version supports Finger, Whois, TFTP, Telnet, POP3, FTP,
NNTP, SMTP, and some miscellaneous protocols like Time and Echo as well
as BSD R command support. The purpose of the library is to provide
fundamental protocol access, not higher-level abstractions.

%package javadoc
Summary:    API documentation for %{name}

%description javadoc
%{summary}.

%prep
%{gpgverify} --keyring='%{SOURCE2}' --signature='%{SOURCE1}' --data='%{SOURCE0}'
%autosetup -n commons-net-%{version}-src

%pom_remove_plugin :exec-maven-plugin

# Fails with "Coverage checks have not been met."
%pom_remove_plugin org.jacoco:jacoco-maven-plugin

%pom_remove_dep org.apache.ftpserver:ftpserver-core

# Disable tests that rely on networking to be available and working.
# Depending on host configuration, on different systems they fail with
# errors such as "Connection timed out", "Address already in use",
# "Temporary failure in name resolution" etc.
rm \
src/test/java/org/apache/commons/net/chargen/CharGenUDPClientTest.java \
src/test/java/org/apache/commons/net/daytime/DaytimeTCPClientTest.java \
src/test/java/org/apache/commons/net/daytime/DaytimeUDPClientTest.java \
src/test/java/org/apache/commons/net/discard/DiscardUDPClientTest.java \
src/test/java/org/apache/commons/net/echo/EchoUDPClientTest.java \
src/test/java/org/apache/commons/net/ftp/AbstractFtpsTest.java \
src/test/java/org/apache/commons/net/ftp/FTPClientTransferModeTest.java \
src/test/java/org/apache/commons/net/ftp/FTPSClientTest.java \
src/test/java/org/apache/commons/net/ftp/NoProtocolSslConfigurationProxy.java \
src/test/java/org/apache/commons/net/tftp/TFTPAckPacketTest.java \
src/test/java/org/apache/commons/net/tftp/TFTPDataPacketTest.java \
src/test/java/org/apache/commons/net/tftp/TFTPErrorPacketTest.java \
src/test/java/org/apache/commons/net/tftp/TFTPReadRequestPacketTest.java \
src/test/java/org/apache/commons/net/tftp/TFTPServerPathTest.java \
src/test/java/org/apache/commons/net/tftp/TFTPTest.java \
src/test/java/org/apache/commons/net/tftp/TFTPWriteRequestPacketTest.java \
src/test/java/org/apache/commons/net/time/TimeTCPClientTest.java \
src/test/java/org/apache/commons/net/time/TimeUDPClientTest.java \

%mvn_file : commons-net %{name}
%mvn_alias : org.apache.commons:commons-net

%build
%mvn_build -- -Dcommons.osgi.symbolicName=org.apache.commons.net

%install
%mvn_install

%files -f .mfiles
%doc README.md RELEASE-NOTES.txt
%license LICENSE.txt NOTICE.txt

%files javadoc -f .mfiles-javadoc
%license LICENSE.txt NOTICE.txt


%changelog
* Sun Sep 01 2024 neoclust <neoclust> 3.11.1-1.mga10
+ Revision: 2092454
- New version 3.11.1

* Thu Jun 20 2024 daviddavid <daviddavid> 3.11.0-2.mga10
+ Revision: 2075838
- Disable more network-reliant tests

* Wed Jun 12 2024 daviddavid <daviddavid> 3.11.0-1.mga10
+ Revision: 2072834
- Update to upstream version 3.11.0

* Tue May 21 2024 ns80 <ns80> 3.10.0-1.mga10
+ Revision: 2065600
- new version 3.10.0 for java 21

* Thu Sep 14 2023 daviddavid <daviddavid> 3.9.0-1.mga10
+ Revision: 1986580
- Update to upstream version 3.9.0

* Sat Jul 01 2023 daviddavid <daviddavid> 3.8.0-2.mga9
+ Revision: 1963357
- backport upstream patch to fix CVE-2021-37533 (mga#31228)

* Thu Sep 08 2022 neoclust <neoclust> 3.8.0-1.mga9
+ Revision: 1886045
- New version 3.8.0

* Mon Jul 25 2022 neoclust <neoclust> 3.6-17.mga9
+ Revision: 1871489
- Rebuild against java17
+ umeabot <umeabot>
- Mageia 9 Mass Rebuild

* Sun Aug 23 2020 neoclust <neoclust> 3.6-5.mga8
+ Revision: 1618229
- Rebuild against java11

* Sat Feb 15 2020 umeabot <umeabot> 3.6-4.mga8
+ Revision: 1527536
- Mageia 8 Mass Rebuild

* Thu Jul 18 2019 daviddavid <daviddavid> 3.6-3.mga8
+ Revision: 1422300
- Rebuild to regenerate OSGi metadata

* Wed Dec 12 2018 daviddavid <daviddavid> 3.6-2.mga7
+ Revision: 1340718
- rebuild against fixed apache-commons-parent (fixes osgi meta)

* Mon Dec 10 2018 daviddavid <daviddavid> 3.6-1.mga7
+ Revision: 1339716
- new version: 3.6 (sync with fc29)

* Thu Sep 20 2018 umeabot <umeabot> 3.4-3.mga7
+ Revision: 1277591
- Mageia 7 Mass Rebuild

* Mon Feb 22 2016 neoclust <neoclust> 3.4-2.mga6
+ Revision: 975998
- Rebuild against new apache-commons-*

* Sun Dec 20 2015 zezinho <zezinho> 3.4-1.mga6
+ Revision: 912451
- new version

* Thu Dec 25 2014 pterjan <pterjan> 3.3-9.mga5
+ Revision: 805572
- Clean rebuild

* Tue Dec 16 2014 pterjan <pterjan> 3.3-8.mga5
+ Revision: 803565
- Bump release
+ dmorgan <dmorgan>
- Restore from Obsolete
+ sander85 <sander85>
- Depends on broken java stack

* Wed Oct 15 2014 umeabot <umeabot> 3.3-7.mga5
+ Revision: 743105
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 3.3-6.mga5
+ Revision: 677819
- Mageia 5 Mass Rebuild

* Tue Dec 31 2013 dmorgan <dmorgan> 3.3-5.mga4
+ Revision: 563619
- Disable tests

* Tue Oct 22 2013 umeabot <umeabot> 3.3-4.mga4
+ Revision: 545646
- Mageia 4 Mass Rebuild

* Wed Oct 16 2013 dmorgan <dmorgan> 3.3-3.mga4
+ Revision: 501524
- Build with xmvn

* Thu Jul 11 2013 dmorgan <dmorgan> 3.3-2.mga4
+ Revision: 453195
- Build with xmvn

* Mon Jul 08 2013 dmorgan <dmorgan> 3.3-1.mga4
+ Revision: 451323
- New version

* Fri Jan 11 2013 umeabot <umeabot> 3.1-2.mga3
+ Revision: 345815
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Wed Sep 12 2012 dmorgan <dmorgan> 3.1-1.mga3
+ Revision: 292662
- New version

* Mon Jun 25 2012 dmorgan <dmorgan> 2.2-5.mga3
+ Revision: 263654
- Use maven 3 to build

* Wed Apr 27 2011 dmorgan <dmorgan> 2.2-4.mga1
+ Revision: 92244
- Rebuild after bootstrapping
- imported package apache-commons-net


* Wed Feb 09 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.2-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Fri Dec 10 2010 Stanislav Ochotnicky <sochotnicky@redhat.com> - 2.2-1
- Replace maven plugins with apache-commons-parent for BR
- Versionless jars and javadocs
- Rebase to latest upstream version

* Thu Jul  8 2010 Stanislav Ochotnicky <sochotnicky@redhat.com> - 2.0-6
- Add license to javadoc subpackage

* Thu May 20 2010 Stanislav Ochotnicky <sochotnicky@redhat.com> - 2.0-5
- Fix maven depmap JPP name to short_name

* Wed May 19 2010 Stanislav Ochotnicky <sochotnicky@redhat.com> - 2.0-4
- Ignore test failure

* Wed May 12 2010 Stanislav Ochotnicky <sochotnicky@redhat.com> - 2.0-3
- Rename jakarta-commons-net to apache-commons-net and drop EPOCH
- Build with maven
- Clean up whole spec

* Thu Aug 13 2009 Alexander Kurtakov <akurtako@redhat.com> 0:2.0-2
- Set maven.repo.local.

* Thu Aug 13 2009 Alexander Kurtakov <akurtako@redhat.com> 0:2.0-1
- Update to upstream 2.0.

